Learn R Programming

imprinting (version 0.1.1)

get_country_inputs_1997_to_present: Return raw flu surveillance data for a specific country

Description

Load and return a tibble containing raw influenza surveillance data for the country of interest. Data are from WHO Flu Mart.

Usage

get_country_inputs_1997_to_present(country, max_year)

Value

A tibble with the following columns:

  • Country: name of WHO region

  • Year: calendar year of surveillance

  • n_processed: total specimens processed

Arguments

country

name of country. Run show_available_countries() for a list of options.

max_year

results will be output for all available years up to max_year.

Examples

Run this code
get_country_inputs_1997_to_present("Aruba", 1998)
get_country_inputs_1997_to_present("Honduras", 2022)

Run the code above in your browser using DataLab