Learn R Programming

imprinting (version 0.1.1)

show_available_countries: Show a list of all available countries

Description

Lists all available countries, with valid spelling and formatting. Each country in the list matches or can be mapped to a country with data in WHO Flu Mart. (Note: for convenience, this package sometimes uses different country names or spellings than Flu Mart.)

Usage

show_available_countries()

Arguments

Value

A data frame of valid country names.

Examples

Run this code
show_available_countries()

Run the code above in your browser using DataLab