powered by
Load and return a tibble containing raw influenza surveillance data for the country of interest. Data are from WHO Flu Mart.
get_country_inputs_1997_to_present(country, max_year)
A tibble with the following columns:
Country: name of WHO region
Country
Year: calendar year of surveillance
Year
n_processed: total specimens processed
n_processed
name of country. Run show_available_countries() for a list of options.
show_available_countries()
results will be output for all available years up to max_year.
max_year
get_country_inputs_1997_to_present("Aruba", 1998) get_country_inputs_1997_to_present("Honduras", 2022)
Run the code above in your browser using DataLab