Learn R Programming

imprinting (version 0.1.1)

get_regional_inputs_1997_to_present: Return raw flu surveillance data for a specific WHO region

Description

Load and return a tibble containing raw influenza surveillance data, aggregated across all countries in the WHO region of interest. Data are from WHO Flu Mart.

Usage

get_regional_inputs_1997_to_present(region, max_year)

Value

A tibble with the following columns:

  • WHOREGION: name of WHO region.

  • Year: calendar year .

  • n_H1N1, n_H2N2, n_H3N2: number of influenza specimens that tested positive for each influenza A subtype.

  • n_A: total specimens positive for influenza A (= n_H1N1 + n_H2N2 + n_H3N2).

  • n_BYam, n_BVic: number of specimens positive for each lineage of influenza B: Victoria or Yamagata.

  • n_B: total specimens positive for influenza B.

  • n_processed: total specimens processed.

Arguments

region

name of WHO region. Run show_available_regions() for a list of options.

max_year

results will be output for all available years up to max_year.

Examples

Run this code
get_regional_inputs_1997_to_present("americas", 2017)

Run the code above in your browser using DataLab